variable name or names (they must be on matching grids)
ncsub
matrix of start, count columns
curvilinear
length two character vector with names of subdatasets holding longitude and latitude values for all raster cells.
Details
The following logic is applied to coordinate axes. If any coordinate axes have
regularly spaced coordinates they are reduced to the
offset/delta form with 'affine = c(0, 0)', otherwise the values of the coordinates
are stored. If the data has two or more dimensions and the first two are regular
they are nominated as the 'raster' for plotting.
If `var` is not set the first set of variables on a shared grid is used.
It's supposed to be the grid with the most dimensions, but there's no control
yet (see `ncmeta::nc_grids(.x)` for the current assumption).
start and count columns of ncsub must correspond to the variable dimemsion (nrows)
and be valid index using `ncdf4::ncvar_get` convention (start is 1-based).