Extract cell values at point locations, possibly using interpolation
st_extract(x, ...)# S3 method for stars
st_extract(x, ...)
# S3 method for stars_proxy
st_extract(x, pts, ..., method = "near", cellsize = 1e-07, debug = FALSE)
object of class stars or stars_proxy
passed on to next method
object of class sf or sfc with POINT geometries
interpolation method, see st_warp
numeric; cellsize chosen for the sampling cell.
logical; if TRUE, do not remove the destination grid file and print its name;
if x has more dimensions than only x and y (raster), an
object of class stars with POINT geometries replacing x and y raster
dimensions; otherwise an object of sf.