Move raster offset such that grid start at row/col (1,1)
Source:R/proxy.R, R/subset.R
st_normalize.RdMove raster offset such that grid start at row/col (1,1)
Details
the `stars_proxy` method does nothing, but raises an error when a raster does not start at cell (1,1)
the `stars` method "moves" the `offset` of the raster dimensions, such that the `from` field becomes `(1,1)` for the raster dimensions; as a side effect, it moves the raster dimensions `x` and `y` to first and second position. If the `from` field is already `(1,1)` or the object does not have raster dimensions it does nothing.